package header

type ResponseHeader interface {
	Value(key string) string
	Set(key string, value string)
	Remove(key string)
	Finalize() []byte
}

type responseHeader struct {
	startLine []byte
	headers   map[string]string
}

type RequestHeader interface {
	Value(key string) string
	Set(key string, value string)
	Remove(key string)
	Finalize() []byte
	Method() string
	Path() string
	Version() string
}
type requestHeader struct {
	method    string
	path      string
	version   string
	startLine []byte
	headers   map[string]string
}
